@@ -128,7 +128,15 @@ from scipy.misc import comb as SPcomb
 from scipy import sparse as scsp
 
 import SparseGrids as SG
-import orthpol
+try:
+    import orthpol
+    ORTHPOL_SUPPORT = True
+except ImportError:
+    ORTHPOL_SUPPORT = False
+    warnings.simplefilter("default")
+    warnings.warn("SpectralToolbox.Spectral1D: The orthpol pacakge is not installed on this machine. Functionalities associated with this package are disabled.", ImportWarning)
+else:
+    warnings.resetwarnings()
 
 JACOBI = 'Jacobi'
 HERMITEP = 'HermiteP'
@@ -218,19 +226,20 @@ class Poly1D(object):
         if (poly in AVAIL_POLY):
             if (poly == JACOBI):
                 if len(params) != 2:
-                    print >> self.sdout, "The number of parameters inserted for the polynomial of type '%s' is not correct" % poly
+                    raise AttributeError("The number of parameters inserted for the polynomial of type '%s' is not correct" % poly)
                     return
             if ((poly == LAGUERREP) or (poly == LAGUERREF)):
                 if len(params) != 1:
-                    print >> self.sdout, "The number of parameters inserted for the polynomial of type '%s' is not correct" % poly
+                    raise AttributeError("The number of parameters inserted for the polynomial of type '%s' is not correct" % poly)
                     return
             if ((poly == ORTHPOL)):
+                if not ORTHPOL_SUPPORT:
+                    raise ImportError("The orthpol package is not installed on this machine.")
                 if len(params) != 11:
                     print >> self.sdout, "The number of parameters inserted for the polynomial of type '%s' is not correct" % poly
                     return
         else:
-            print >> self.sdout, "The inserted type of polynomial is not available."
-            return
+            raise AttributeError("The inserted type of polynomial is not available.")
         self.poly = poly
         self.params = params
     
@@ -623,6 +632,8 @@ class Poly1D(object):
         
         .. note:: For further details see [4]_
         """
+        if not ORTHPOL_SUPPORT:
+            raise ImportError("The orthpol package is not installed on this machine.")
 
         eps = orthpol.d1mach(3)
         
@@ -668,6 +679,9 @@ class Poly1D(object):
         .. note:: For further details see [4]_
         """
         
+        if not ORTHPOL_SUPPORT:
+            raise ImportError("The orthpol package is not installed on this machine.")
+
         eps = orthpol.d1mach(3)
         
         # Unpack params
@@ -711,6 +725,9 @@ class Poly1D(object):
         
         .. note:: For further details see [4]_
         """
+
+        if not ORTHPOL_SUPPORT:
+            raise ImportError("The orthpol package is not installed on this machine.")
         
         eps = orthpol.d1mach(3)
         
@@ -912,9 +929,28 @@ class Poly1D(object):
             if ( AlmostEqual(alpha,-0.5) and AlmostEqual(beta,-0.5) ):
                 return self.__ChebyshevP(x,N)
             else:
-                (al,be,ierr) = orthpol.drecur(N+1,6,alpha,beta)
-                v = orthpol.polyeval(x,N,al,be)
-                return v
+                if ORTHPOL_SUPPORT:
+                    (al,be,ierr) = orthpol.drecur(N+1,6,alpha,beta)
+                    v = orthpol.polyeval(x,N,al,be)
+                    return v
+                else:
+                    PL = np.zeros((N+1,len(x)))
+                    gamma0 = 2**(alpha+beta+1)/(alpha+beta+1)*gammaF(alpha+1)*gammaF(beta+1)/gammaF(alpha+beta+1)
+                    PL[0,:] = 1.0/np.sqrt(gamma0)
+                    if (N == 0): return PL[0,:]
+                    gamma1 = (alpha+1.)*(beta+1.)/(alpha+beta+3.)*gamma0
+                    PL[1,:] = ((alpha+beta+2.)*x/2. + (alpha-beta)/2.)/np.sqrt(gamma1)
+                    if (N == 1): return PL[N,:]
+                    # Recurrence
+                    aold = 2./(2.+alpha+beta)*np.sqrt((alpha+1.)*(beta+1.)/(alpha+beta+3.))
+                    for i in range(1,N):
+                        h1 = 2.*i+alpha+beta
+                        anew = 2./(h1+2.)*np.sqrt( (i+1.)*(i+1.+alpha+beta)*(i+1.+alpha)*(i+1.+beta)/(h1+1.)/(h1+3.) )
+                        bnew = - (alpha**2. - beta**2.)/h1/(h1+2.)
+                        PL[i+1,:] = 1.0 / anew*( -aold*PL[i-1,:] + np.multiply((x-bnew),PL[i,:]) )
+                        aold = anew
+                    
+                    return PL[N,:]
             
     def __LegendreP(self,r, N):
         """
@@ -1310,7 +1346,8 @@ class Poly1D(object):
         
         .. note:: For further information see [4]_
         """
-        import orthpol
+        if not ORTHPOL_SUPPORT:
+            raise ImportError("The orthpol package is not installed on this machine.")
 
         eps = orthpol.d1mach(3)
         
@@ -1523,10 +1560,12 @@ class Poly1D(object):
         else:
             print >> self.sdout, "[Spectral1D]: Gamma function not implemented yet for the selected polynomial %s" % self.poly
     
-    def __GradJacobiVandermonde(self,r,N,k,norm):
+    def __GradJacobiVandermondeORTHPOL(self,r,N,k,norm):
         if (self.poly != JACOBI):
-            print >> self.sdout, "The method __GradJacobiP cannot be called with the actual type of polynomials. Actual type: '%s'" % self.poly
+            raise ImportError( "The method __GradJacobiP cannot be called with the actual type of polynomials. Actual type: '%s'" % self.poly )
         else:
+            if not ORTHPOL_SUPPORT:
+                raise ImportError("The orthpol package is not installed on this machine.")
             # Unpack parameters
             alpha,beta = self.params
             
@@ -1558,8 +1597,8 @@ class Poly1D(object):
             * ``V`` = (2d-array(``MxN``),float) Generalized Vandermonde matrix
         """
         
-        if (self.poly == JACOBI):
-            DVr = self.__GradJacobiVandermonde(r,N,k,norm)
+        if (self.poly == JACOBI) and ORTHPOL_SUPPORT:
+            DVr = self.__GradJacobiVandermondeORTHPOL(r,N,k,norm)
         else:
             DVr = np.zeros((r.shape[0],N+1))
             for i in range(0,N+1):
